@@ -1,14 +1,20 @@
+require 'cgi'
 require 'json'
 require 'time'
 
+require 'debci/test/duration'
+require 'debci/test/expired'
+
 module Debci
 
   # This class represents one test execution.
 
   class Status
 
-    attr_reader :blame
-    attr_accessor :suite, :architecture, :run_id, :package, :version, :date, :status, :previous_status, :duration_seconds, :duration_human, :message, :last_pass_version, :last_pass_date
+    include Debci::Test::Duration
+    include Debci::Test::Expired
+
+    attr_accessor :suite, :architecture, :run_id, :package, :version, :date, :trigger, :status, :previous_status, :duration_seconds, :message, :last_pass_version, :last_pass_date, :requestor
 
     # Returns `true` if this status object represents an important event, such
     # as a package that used to pass started failing, of vice versa.
@@ -16,6 +22,10 @@ module Debci
       [
         [:fail, :pass],
         [:pass, :fail],
+        [:fail, :neutral],
+        [:pass, :neutral],
+        [:neutral, :pass],
+        [:neutral, :fail],
       ].include?([status, previous_status])
     end
 
@@ -23,6 +33,7 @@ module Debci
       {
         :pass => "Pass",
         :fail => "Fail",
+        :neutral => "No tests or all skipped",
         :tmpfail => "Temporary failure",
         :no_test_data => "No test data",
       }.fetch(status, "Unknown")
@@ -79,7 +90,7 @@ module Debci
     # Returns a headline for this status object, to be used as a short
     # description of the event it represents
     def headline
-      msg = "#{package} #{version} #{status.upcase}ED on #{suite}/#{architecture}"
+      msg = "#{package} #{version} #{status.upcase} on #{suite}/#{architecture}"
       if status == :fail && failmsg
         msg += " (#{failmsg})"
       end
@@ -89,7 +100,7 @@ module Debci
     # A longer version of the headline
     # for a new failure, include whether this version previously passed
     def description
-      msg = "The tests for #{package}, version #{version}, #{status.upcase}ED on #{suite}/#{architecture} but have previously #{previous_status.upcase}ED"
+      msg = "The tests for #{package} (version #{version}) resulted in #{status.upcase} on #{suite}/#{architecture}. Previously it was #{previous_status.upcase}"
       msg += case extended_status
         when :fail_passed_current
           " for the current version."
@@ -100,14 +111,6 @@ module Debci
         end
     end
 
-    def blame=(value)
-      if value.is_a?(Array)
-        @blame = value
-      else
-        @blame = []
-      end
-    end
-
     # Returns the amount of time since the date for this status object
     def time
       days = (Time.now - date)/86400
@@ -154,27 +157,30 @@ module Debci
       status.run_id = data['run_id'] || data['date']
       status.package = data['package']
       status.version = data['version']
+      status.requestor = data['requestor']
       status.date =
         begin
-          Time.parse(data.fetch('date', 'unknown') + ' UTC')
+          d = data['date']
+          d ||= data['created_at']
+          d ||= 'unknown'
+          Time.parse(d + ' UTC')
         rescue ArgumentError
           nil
         end
-      status.status = data.fetch('status', :unknown).to_sym
-      status.previous_status = data.fetch('previous_status', :unknown).to_sym
-      status.blame = data['blame']
+      status.trigger = data['trigger']
+      status.status = (data['status'] || :unknown).to_sym
+      status.previous_status = (data['previous_status'] || :unknown).to_sym
       status.duration_seconds =
         begin
-          Integer(data.fetch('duration_seconds', 0))
+          Integer(data['duration_seconds'] || 0)
         rescue ArgumentError
           nil
         end
-      status.duration_human = data['duration_human']
       status.message = data['message']
       status.last_pass_version = data.fetch('last_pass_version', 'unknown')
       status.last_pass_date =
         begin
-          Time.parse(data.fetch('last_pass_date', 'unknown') + ' UTC')
+          Time.parse((data['last_pass_date'] || 'unknown') + ' UTC')
         rescue ArgumentError
           nil
         end
@@ -182,20 +188,21 @@ module Debci
       status
     end
 
-    def expired?
-      days = Debci.config.data_retention_days.to_i
-      if days > 0
-        retention_window = days * (24*60*60)
-        Time.now > self.date + retention_window
-      else
-        false
-      end
+    def newer?(days)
+      return true if days <= 0
+      (Time.now - date) < days * (24 * 60 * 60)
     end
 
     def inspect
       "<#{suite}/#{architecture} #{status}>"
     end
 
+    def blacklisted?
+      Debci.blacklist.include?(
+        package, suite: suite, arch: architecture, version: version
+      )
+    end
+
   end
 
 end
