@@ -55,6 +55,8 @@ debci_sendmail_to="${debci_sendmail_to:-%s@localhost}"
 debci_url_base="${debci_url_base:-http://localhost:8080}"
 debci_artifacts_url_base="${debci_artifacts_url_base:-}"
 debci_database_url="${debci_database_url:-sqlite3://$debci_data_basedir/debci.sqlite3?timeout=5000}"
+debci_pending_status_per_page="${debci_pending_status_per_page:-50}"
+debci_failing_packages_per_page="${debci_failing_packages_per_page:-50}"
 
 debci_secrets_dir=${debci_secrets_dir:-$(readlink -f "${debci_base_dir}/secrets")}
 
@@ -156,6 +158,9 @@ debci_group=$(stat -c %G "${debci_data_basedir}")
 
 debci_amqp_queue=${debci_amqp_queue:-"debci-tests-${debci_arch}-${debci_backend}"}
 
+# hide password when displaying AMPQ server
+debci_amqp_server_display="$(echo "$debci_amqp_server" | sed -e 's#:[^/]*@#:*********@#')"
+
 debci_lock_dir=${debci_lock_dir:-/var/lock}
 
 # per-suite/architecture lock/timestamp files
@@ -173,6 +178,11 @@ debci_data_retention_days=${debci_data_retention_days:-180}
 # extra arguments for autopkgtest
 debci_autopkgtest_args="${debci_autopkgtest_args:-}"
 
+# session secret for the web interface
+debci_session_secret="${debci_session_secret:-}"
+
+# page to display when authentication fails
+debci_auth_fail_page="${debci_auth_fail_page:-}"
 
 for dir in \
   "${debci_base_dir}/backends/${debci_backend}" \
