@@ -1,3 +1,4 @@
+require "spec_helper"
 require 'debci'
 require 'debci/repository'
 
@@ -6,10 +7,7 @@ require 'fileutils'
 require 'json'
 
 describe Debci::Repository do
-
   before(:all) do
-    @now = Time.now.strftime('%Y%m%d_%H%M%S')
-
     @datadir = Dir.mktmpdir
     mkdir_p 'packages/unstable/amd64/r/rake'
     mkdir_p 'packages/unstable/i386/r/rake'
@@ -18,15 +16,18 @@ describe Debci::Repository do
 
     mkdir_p 'packages/unstable/amd64.old'
 
-    past_status 'packages/unstable/amd64/r/rake', { 'status' => 'pass', 'previous_status' => 'fail' }, '20140412_212642'
-    latest_status 'packages/unstable/amd64/r/rake', { 'status' => 'fail', 'previous_status' => 'pass' }
-    latest_status 'packages/testing/amd64/r/rake', { 'status' => 'fail', 'previous_status' => 'pass'}
+    history 'packages/testing/amd64/r/rake', [
+      { 'status' => 'fail', 'date' => '2014-08-01 11:11:12' },
+      { 'status' => 'pass', 'date' => '2014-07-07 12:12:15' }
+    ]
 
-    history 'packages/unstable/amd64/r/rake', [{'status' => 'fail', 'date' => '2014-08-01 11:11:12'},
-                                               {'status' => 'pass', 'date' => '2014-07-07 12:12:15'},
-                                               {'status' => 'tmpfail', 'date' => '2014-03-01 14:15:30'},
-                                               {'status' => 'fail', 'date' => '2015-03-01 14:15:30'},
-                                               {'status' => 'pass', 'date' => '2016-03-01 14:15:30'}]
+    history 'packages/unstable/amd64/r/rake', [
+      { 'status' => 'fail', 'date' => '2014-08-01 11:11:12' },
+      { 'status' => 'pass', 'date' => '2014-07-07 12:12:15' },
+      { 'status' => 'tmpfail', 'date' => '2014-03-01 14:15:30' },
+      { 'status' => 'fail', 'date' => '2015-03-01 14:15:30' },
+      { 'status' => 'pass', 'date' => '2016-03-01 14:15:30' }
+    ]
 
     mkdir_p 'packages/unstable/amd64/r/rake-compiler'
     mkdir_p 'packages/unstable/i386/r/rake-compiler'
@@ -40,8 +41,8 @@ describe Debci::Repository do
     mkdir_p 'packages/testing/amd64/r/ruby-ffi'
     mkdir_p 'packages/testing/i386/r/ruby-ffi'
 
-    latest_status 'packages/unstable/amd64/r/ruby-ffi', {'status' => 'tmpfail',
-                                                         'previous_status' => 'pass' }
+    latest_status 'packages/unstable/amd64/r/ruby-ffi', 'status' => 'tmpfail',
+                                                        'previous_status' => 'pass'
 
     mkdir_p 'packages/unstable/amd64/r/rubygems-integration'
     mkdir_p 'packages/unstable/i386/r/rubygems-integration'
@@ -49,73 +50,75 @@ describe Debci::Repository do
     mkdir_p 'packages/testing/i386/r/rubygems-integration'
 
     # platform specific issue
-    latest_status 'packages/unstable/amd64/r/rubygems-integration', {
-      'status' => 'pass',
-      'previous_status' => 'pass',
-    }
-    latest_status 'packages/unstable/i386/r/rubygems-integration', {
-      'status' => 'fail',
-      'previous_status' => 'fail',
-    }
+    latest_status 'packages/unstable/amd64/r/rubygems-integration',
+                  'status' => 'pass',
+                  'previous_status' => 'pass'
+    latest_status 'packages/unstable/i386/r/rubygems-integration',
+                  'status' => 'fail',
+                  'previous_status' => 'fail'
 
     # NOT a platform specific issue - tmpfail should be ignored
     mkdir_p 'packages/unstable/amd64/r/racc'
     mkdir_p 'packages/unstable/i386/r/racc'
-    latest_status 'packages/unstable/amd64/r/racc', {
-      'status' => 'pass',
-      'previous_status' => 'pass',
-    }
-    latest_status 'packages/unstable/i386/r/racc', {
-      'status' => 'tmpfail',
-      'previous_status' => 'pass',
-    }
+    latest_status 'packages/unstable/amd64/r/racc',
+                  'status' => 'pass',
+                  'previous_status' => 'pass'
+    latest_status 'packages/unstable/i386/r/racc',
+                  'status' => 'tmpfail',
+                  'previous_status' => 'pass'
 
     mkdir_p 'packages/unstable/amd64/s/slowpackage'
-    latest_status 'packages/unstable/amd64/s/slowpackage', {
-      'status' => 'pass',
-      'duration_seconds' => 5000,
-    }
-  end
+    latest_status 'packages/unstable/amd64/s/slowpackage',
+                  'status' => 'pass',
+                  'duration_seconds' => 5000
 
-  attr_reader :now
+    mkdir_p 'packages/unstable/amd64/n/newsworthypacakge'
+    latest_status 'packages/unstable/amd64/n/newsworthypacakge',
+                  'status' => 'pass',
+                  'previous_status' => 'fail'
+  end
 
   after(:all) do
     FileUtils.rm_rf @datadir
   end
 
   def mkdir_p(path)
-    FileUtils.mkdir_p(File.join@datadir, path)
+    FileUtils.mkdir_p(File.join(@datadir, path))
   end
 
-  def past_status(path, data, run_id)
-    package = File.basename(path)
-    File.open(File.join(@datadir, path, run_id + '.json'), 'w') do |f|
-      f.write(JSON.dump({ 'package' => package, 'run_id' => run_id }.merge(data)))
-    end
+  def fetch_run_id
+    @run_id ||= 0
+    @run_id += 1
   end
 
   def history(path, data)
+    previous_status = nil
+    data.each do |entry|
+      entry['run_id'] = fetch_run_id
+      entry['previous_status'] = previous_status if previous_status
+      previous_status = entry['status']
+    end
     File.open(File.join(@datadir, path, 'history.json'), 'w') do |f|
       f.write(JSON.pretty_generate(data))
     end
   end
 
   def latest_status(path, data)
-    run_id = now
-    past_status(path, data, run_id)
-    Dir.chdir(File.join(@datadir, path)) do
-      FileUtils.ln_s(run_id + '.json', 'latest.json')
+    package = File.basename(path)
+    run_id = fetch_run_id
+    File.open(File.join(@datadir, path, 'latest.json'), 'w') do |f|
+      f.write(JSON.dump({ 'package' => package, 'run_id' => run_id }.merge(data)))
     end
   end
 
   let(:repository) { Debci::Repository.new(@datadir) }
 
   it 'knows about architectures' do
-    expect(repository.architectures).to eq(['amd64', 'i386'])
+    expect(repository.architectures).to eq(%w[amd64 i386])
   end
 
   it 'knows about suites' do
-    expect(repository.suites).to eq(['testing', 'unstable'])
+    expect(repository.suites).to eq(%w[testing unstable])
   end
 
   it 'knows about prefixes' do
@@ -139,7 +142,7 @@ describe Debci::Repository do
   end
 
   it 'raises an exception when package is not found' do
-    expect(lambda { repository.find_package('doesnotexist') }).to raise_error(Debci::Repository::PackageNotFound)
+    expect(-> { repository.find_package('doesnotexist') }).to raise_error(Debci::Repository::PackageNotFound)
   end
 
   it 'searches for packages with exact match' do
@@ -156,8 +159,26 @@ describe Debci::Repository do
     expect(statuses.first.length).to eq(2) # 2 architectures
     statuses.flatten.each do |s|
       expect(s).to be_a(Debci::Status)
-      expect(['unstable', 'testing']).to include(s.suite)
-      expect(['amd64', 'i386']).to include(s.architecture)
+      expect(%w[unstable testing]).to include(s.suite)
+      expect(%w[amd64 i386]).to include(s.architecture)
+    end
+  end
+
+  it 'fetches blacklisted status for packages' do
+    statuses = repository.all_status_for('rake')
+    # Blacklisting testing_amd64, unstable_i386
+    testing_amd64 = statuses.first.first
+    unstable_i386 = statuses.second.second
+
+    allow(testing_amd64).to receive(:blacklisted?).and_return(true)
+    allow(unstable_i386).to receive(:blacklisted?).and_return(true)
+
+    statuses = repository.blacklisted_status_for('rake')
+
+    expect(statuses.length).to eq(2) # 2 suite
+    statuses.flatten.each do |s|
+      expect(s).to be_a(Debci::Status)
+      expect([testing_amd64, unstable_i386]).to include(s)
     end
   end
 
@@ -166,8 +187,8 @@ describe Debci::Repository do
     expect(statuses.length).to eq(3)
     statuses.each do |s|
       expect(s).to be_a(Debci::Status)
-      expect(['unstable', 'testing']).to include(s.suite)
-      expect(['amd64', 'i386']).to include(s.architecture)
+      expect(%w[unstable testing]).to include(s.suite)
+      expect(%w[amd64 i386]).to include(s.architecture)
     end
   end
 
@@ -177,16 +198,18 @@ describe Debci::Repository do
   end
 
   it 'sorts news with most recent first' do
-    glob = File.join(@datadir, 'packages/{unstable}/{amd64}/r/rake/[0-9]*.json')
-    statuses_reversed = Dir.glob(glob).sort_by { |f| File.basename(f) }.reverse
-
     expect(repository).to receive(:architectures).and_return(['amd64'])
     expect(repository).to receive(:suites).and_return(['unstable'])
-    expect(Dir).to receive(:glob).with(glob).and_return(statuses_reversed)
-
     news = repository.news_for('rake')
 
-    expect(news.first.run_id).to eq(now)
+    first = news[0]
+    second = news[1]
+    expect(first.run_id).to be > second.run_id
+  end
+
+  it 'produces global news' do
+    news = repository.global_news
+    expect(news[0].package).to eq('newsworthypacakge')
   end
 
   it 'supports the Package class' do
@@ -242,13 +265,27 @@ describe Debci::Repository do
     end
   end
 
+  it 'knows which packages are failing' do
+    failing_packages = repository.failing_packages
+
+    expect(failing_packages).to be_a(Array)
+    expect(failing_packages.length).to be >= 1
+
+    package = failing_packages.find { |pkg| pkg.name == 'rubygems-integration' }
+    expect(package). to be_a(Debci::Package)
+    expect(package.name). to eq('rubygems-integration')
+
+    statuses = package.status.flatten.map(&:status)
+    expect(statuses).to include(:fail)
+  end
+
   it 'knows about slow-running tests' do
     slow = repository.slow_packages
     expect(slow).to be_a(Array)
     expect(slow.length).to be >= 1
 
-    status = slow.find { |status| status.package == 'slowpackage' }
-    expect(status).to be_a(Debci::Status)
+    slow_status = slow.find { |status| status.package == 'slowpackage' }
+    expect(slow_status).to be_a(Debci::Status)
   end
 
   it 'knows about platform-specific issues' do
